@@ -8,7 +8,7 @@
  */
 
 /*
- * $Id: main.c,v 1.100 2004/10/12 14:23:18 florian Exp $
+ * $Id: main.c,v 1.102 2004/10/16 22:21:17 florian Exp $
  *
  */
 
@@ -54,6 +54,7 @@ GtkWidget *list_view;
 GtkWidget *search_entry;
 GtkWidget *popup_menu;
 GtkWidget *bluetooth_menu_item;
+GtkWidget *irda_menu_item;
 guint menu_uid;
 gboolean mode_landscape;
 gboolean mode_large_screen;
@@ -76,7 +77,7 @@ menu_do_edit (void)
 {
   struct person *p;
   p = db_get_by_uid (menu_uid);
-  edit_person (p, FALSE);
+  edit_person (p,  _("Edit Contact"), FALSE);
 }
 
 static void
@@ -156,7 +157,7 @@ new_contact (GtkWidget * widget, gpointer d)
   gtk_widget_set_sensitive (new_button, FALSE);
   gtk_widget_set_sensitive (edit_button, FALSE);
   p = new_person ();
-  edit_person (p, TRUE);
+  edit_person (p, _("New Contact"), FALSE);
 }
 
 static void
@@ -178,7 +179,7 @@ edit_contact (GtkWidget * widget, gpointer d)
       gtk_widget_set_sensitive (edit_button, FALSE);
       gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 1, &uid, -1);
       p = db_get_by_uid (uid);
-      edit_person (p, FALSE);
+      edit_person (p, _("Edit Contact"), FALSE);
     }
 }
 
@@ -1085,7 +1086,12 @@ list_button_press_event (GtkWidget *widget, GdkEventButton *b, GtkListStore *lis
                 gtk_widget_show (bluetooth_menu_item);
               else
                 gtk_widget_hide (bluetooth_menu_item);
-          
+              
+              if (export_irda_available ())
+                gtk_widget_show (irda_menu_item);
+              else
+                gtk_widget_hide (irda_menu_item);
+              
               gtk_menu_popup (GTK_MENU (popup_menu), 
                               NULL, NULL, NULL, widget, b->button, b->time);
             }
@@ -1114,6 +1120,7 @@ static GtkItemFactoryEntry popup_items[] =
   { "/Delete",		    NULL, menu_do_delete,         0, "<StockItem>", GTK_STOCK_DELETE },
   { "/Save as ...",	    NULL, menu_do_save,           0, "<Item>" },
   { "/Send via Bluetooth", NULL, menu_do_send_bluetooth, 0, "<Item>", },
+  { "/Send via Irda", NULL, menu_do_send_irda, 0, "<Item>", },
 };
 
 static GtkWidget *
@@ -1129,6 +1136,7 @@ create_popup (GtkWidget *window)
 				 popup_items, NULL);
 
   bluetooth_menu_item = gtk_item_factory_get_widget (item_factory, "<main>/Send via Bluetooth");
+  irda_menu_item = gtk_item_factory_get_widget (item_factory, "<main>/Send via Irda");
 
   return gtk_item_factory_get_widget (item_factory, "<main>");
 }
@@ -1164,8 +1172,6 @@ create_main (gboolean edit_structure)
   /* screen layout detection */
   size_x = gdk_screen_width();
   size_y = gdk_screen_height();  
-  mode_large_screen = (size_x > 240) && (size_y > 320);
-  mode_landscape = (size_x > size_y);
   size_x /= 4;
   size_y /= 3;
   if (size_x < 240) size_x = 240;
@@ -1398,8 +1404,10 @@ main (int argc, char *argv[])
 {
   int arg;
   gboolean edit_structure = TRUE;
+  gboolean edit_vcard = FALSE;
   gchar *ifile = NULL;
   GtkTreePath *path;
+  gint size_x, size_y;
   
 #ifdef ENABLE_NLS
   setlocale (LC_ALL, "");
@@ -1415,8 +1423,14 @@ main (int argc, char *argv[])
   if (gpe_load_icons (my_icons) == FALSE)
     exit (1);
 
+  /* screen layout detection */
+  size_x = gdk_screen_width();
+  size_y = gdk_screen_height();  
+  mode_large_screen = (size_x > 240) && (size_y > 320);
+  mode_landscape = (size_x > size_y);
+  
   /* check command line args */
-  while ((arg = getopt(argc, argv, "ni:")) >= 0)
+  while ((arg = getopt(argc, argv, "ni:v")) >= 0)
   {
     if (arg == 'n')
       {
@@ -1425,6 +1439,8 @@ main (int argc, char *argv[])
       }
     if (arg == 'i')
 		ifile = optarg;
+    if (arg == 'v')
+      edit_vcard = TRUE;
   }    
 
   /* are we called to import a file? */
@@ -1457,13 +1473,35 @@ main (int argc, char *argv[])
 
   displaymigration_init ();
   
-  if (db_open ())
+ /* we are called to edit a users personal vcard */
+  if (edit_vcard)
+    {
+      struct person *p;
+      const gchar *MY_VCARD = g_strdup_printf("%s/.gpe/user.vcf", 
+                                              g_get_home_dir());
+  
+      if (db_open (TRUE))
+        exit (1);
+      load_well_known_tags ();
+      load_structure ();
+      
+      p = db_get_by_uid (1);
+      if (!p)
+        p = new_person();
+      edit_person (p, _("My Card"), TRUE);
+      gtk_main();
+      if (save_to_file(1, MY_VCARD))
+        gpe_perror_box(_("Saving vcard failed"));
+      exit (EXIT_SUCCESS);
+    }
+    
+   if (db_open (FALSE))
     exit (1);
 
   load_well_known_tags ();
 
   list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
-
+   
   mainw = create_main (edit_structure);
   popup_menu = create_popup (mainw);
   update_categories ();
